<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 719 2006-04-04 18:45:41Z danper $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('core/TroveLink.php');
require_once('core/TroveCategory.php');

/**
 * This class manages the Trove forms
 */
class TroveRenderer {
	private $section = null;
	private $ref_id = null;
	
	const TROVE_DEV_STATUS = 'trove_devstatus';
	const TROVE_LICENSE = 'trove_license';
	const TROVE_OS = 'trove_os';
	const TROVE_SPOKEN_LANGUAGE = 'trove_spokenlanguage';
	const TROVE_PROGRAMMING_LANGUAGE = 'trove_programminglanguage';
	const TROVE_TOPIC = 'trove_topic';
	const TROVE_INTENDED_AUDIENCE = 'trove_intendedaudience';

	
	private $troves;
	
	public function __construct() {
		$this->troves = array(
							self::TROVE_DEV_STATUS,
							self::TROVE_LICENSE,
							self::TROVE_OS,
							self::TROVE_SPOKEN_LANGUAGE,
							self::TROVE_PROGRAMMING_LANGUAGE,
							self::TROVE_TOPIC,
							self::TROVE_INTENDED_AUDIENCE,
							
						);

		$extra_troves = GFConf::get('system.extraTroveRootCategories');	
		$c = new Criteria();
		$c->add(TroveCategoryPeer::TROVE_CATEGORY_ID, $extra_troves, Criteria::IN);
		$categories = TroveCategoryPeer::doSelect($c);
		
		foreach ($categories as $category) {
			$this->troves[] = 'trove_'.$category->getAlias(); 
		}

	}
	
	public function setSection($section) {
		$this->section = $section;
	}
	
	public function setRefId($ref_id) {
		$this->ref_id = $ref_id;
	}
	
	public function getSection() {
		return $this->section;
	}
	
	public function getRefId() {
		return $this->ref_id;
	}
	
	public function showTroveForm($troves = null) {
		if (is_null($troves)) {
			$troves = $this->troves;
		}


		$selected_troves = array();
		if ($_SERVER['REQUEST_METHOD'] == 'POST') {
			foreach ($troves as $trove) {
				if (isset($_POST[$trove]) && is_array($_POST[$trove])) {
					$selected_troves = array_merge($selected_troves, $_POST[$trove]);
				} elseif (isset($_POST[$trove]) && $trove == self::TROVE_DEV_STATUS) {
					$selected_trove_dev_status = $_POST[$trove];
				} elseif (isset($_POST[$trove]) && $trove == self::TROVE_LICENSE) {
					$selected_trove_license = $_POST[$trove];
				}
			}
		} elseif (!is_null($this->section) && !is_null($this->ref_id)) {
			$selected_troves = TroveLinkPeer::getSelectedCategoriesArray($this->section, $this->ref_id);

			// dev_status and license have only one value
			$vals = TroveLinkPeer::getSelectedRootCategoryValues($this->section, $this->ref_id, GFConf::get('system.troveDevStatus'));
			if (!is_array($vals) || count($vals) == 0) {
				$selected_trove_dev_status = null;
			} else {
				$selected_trove_dev_status = $vals[0];
			}
			
			$vals = TroveLinkPeer::getSelectedRootCategoryValues($this->section, $this->ref_id, GFConf::get('system.troveLicense'));
			if (!is_array($vals) || count($vals) == 0) {
				$selected_trove_license = null;
			} else {
				$selected_trove_license = $vals[0];
			}
		} else {
			// no trove information available -- maybe submitting a new item?
			$selected_trove_dev_status = 0;
			$selected_trove_license = 0;
		}
		
		
		$trove_form = SystemUtils::buildFilePath(GFConf::get('system.libDir'), '/wwwlib/forms/TroveEdit-tpl.php');
		$Lang = Language::getSessLang();

		require_once($trove_form);
	}
	
	public function savePOSTData() {
		// make sure section and ref_id are set
		if (is_null($this->section) || is_null($this->ref_id)) {
			throw new Exception('Trove.DataNotSet');
		}
		
		// Generate a map bewteen root categories and their ids
		// (will be used for deleting the links whose roots are
		// these categories)
		$trove_map = array();
		$trove_map[self::TROVE_DEV_STATUS] = GFConf::get('system.troveDevStatus');
		$trove_map[self::TROVE_LICENSE] = GFConf::get('system.troveLicense');
		$trove_map[self::TROVE_OS] = GFConf::get('system.troveOS');
		$trove_map[self::TROVE_SPOKEN_LANGUAGE] = GFConf::get('system.troveSpokenLanguage');
		$trove_map[self::TROVE_PROGRAMMING_LANGUAGE] = GFConf::get('system.troveProgrammingLanguage');
		$trove_map[self::TROVE_TOPIC] = GFConf::get('system.troveTopic');
		$trove_map[self::TROVE_INTENDED_AUDIENCE] = GFConf::get('system.troveIntendedAudience');

		$extra_troves = GFConf::get('system.extraTroveRootCategories');	
		$c = new Criteria();
		$c->add(TroveCategoryPeer::TROVE_CATEGORY_ID, $extra_troves, Criteria::IN);
		$categories = TroveCategoryPeer::doSelect($c);
		
		foreach ($categories as $category) {
			$trove_map['trove_'.$category->getAlias()] = $category->getTroveCategoryId(); 
		}
		
		foreach ($this->troves as $trove) {
			if (isset($_POST['trove_has_'.$trove])) {
				// clean the old information
				$c = new Criteria();
				$c->add(TroveCategoryPeer::ROOT_TROVE_CATEGORY_ID, $trove_map[$trove]);
				$c->addJoin(TroveLinkPeer::TROVE_CATEGORY_ID, TroveCategoryPeer::TROVE_CATEGORY_ID);
				$c->add(TroveLinkPeer::SECTION, $this->section);
				$c->add(TroveLinkPeer::REF_ID, $this->ref_id);
				$links = TroveLinkPeer::doSelect($c);
				foreach ($links as $link) {
					$link->delete();
				}
				
				if ($trove == self::TROVE_DEV_STATUS || $trove == self::TROVE_LICENSE) {
					// these will have only one value
					$troveLink = new TroveLink();
					$troveLink->setSection($this->section);
					$troveLink->setRefId($this->ref_id);
					$troveLink->setTroveCategoryId( Validator::sanitizeInt($_POST[$trove]) );
					$troveLink->save();
				} else {
					// Now create the new links
					if (array_key_exists($trove,$_POST)) {
						foreach ($_POST[$trove] as $trove_id) {
							$troveLink = new TroveLink();
							$troveLink->setSection($this->section);
							$troveLink->setRefId($this->ref_id);
							$troveLink->setTroveCategoryId( Validator::sanitizeInt($trove_id) );
							$troveLink->save();
							
						}
					}
				}
			}
		}
	}
}
?>
