<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 * @date 2006-02-27
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

//
// This code lists Docman
//
//require_once('plugins/news/lib/DocmanPeer.php');
//require_once('plugins/news/lib/Docman.php');

$session = Session::getSession();
$Lang = $session->getLanguage();

require_once('plugins/docman/lib/html/DocmanTemplate.php');
require_once('plugins/docman/lib/InfoParser.php');
require_once('plugins/docman/lib/DocmanTreeRenderer.php');
require_once('plugins/docman/lib/DocmanFolder.php');
require_once('plugins/docman/lib/DocmanFolderPeer.php');
require_once('plugins/docman/lib/DocmanFile.php');
require_once('plugins/docman/lib/DocmanFilePeer.php');
require_once('lib/exceptions/PermissionDeniedException.php');
require_once('html/Paginator.php');
require_once('html/HTMLWidget.php');

$theme = new DocmanTemplate();

$project = GFUrl::getUrl()->getProject();

if (isset($_REQUEST['subdir']) && $_REQUEST['subdir'] > 0) {
	$subdir=Validator::sanitizeInt($_REQUEST['subdir']);
} else {
	$subdir=0;
}

if ($subdir == 0) {
	$c = new Criteria();
	$c->add(DocmanFolderPeer::PROJECT_ID,$project->getProjectId());
	$c->add(DocmanFolderPeer::FOLDER_NAME,'incoming'); // default master folder
	$c->add(DocmanFolderPeer::PARENT_FOLDER_ID,0);
	$Folder = DocmanFolderPeer::doSelectOne($c);
} else {
	$Folder = DocmanFolderPeer::retrieveByPK($subdir);
}

$params = array(
		'project' => $project,
		'feedback' => isset($_REQUEST['feedback']) ? $_REQUEST['feedback'] : (isset($feedback) ? $feedback : ''),
		'title' => $Lang->getText('Docman.BrowsePageTitle')
		);
$theme->header($params);

$parser = new InfoParser($project);
$nested_folders = $parser->getNestedFolders();
$arranged_folders = $parser->getArrangedFolders();

$doctreerenderer = new DocmanTreeRenderer($project,$nested_folders,$arranged_folders);

//$count=count($nested_docs);
//$count = $nested_docs->getRecordCount();
/*$theader=array();
$theader[]= $Lang->getText('Docman.Navigation');
$theader[]= $Lang->getText('Docman.Filename');
$theader[]= $Lang->getText('Docman.Size');
$theader[]= $Lang->getText('Docman.Author');
$theader[]= $Lang->getText('Docman.Locked');
$theader[]= $Lang->getText('Docman.EditFile');
$theader[]= $Lang->getText('Docman.Version');
$theader[]= $Lang->getText('Docman.Downloads');*/

$columns = array(
	$Lang->getText('Docman.Navigation'),
	$Lang->getText('Docman.EditFile'),
	FilesystemPeer::FILE_NAME => $Lang->getText('Docman.Filename'),
	FilesystemPeer::FILE_SIZE => $Lang->getText('Docman.Size'),
	'full_name' => $Lang->getText('Docman.Author'),
	DocmanFilePeer::IS_LOCKED => $Lang->getText('Docman.Locked'),
	DocmanFileVersionPeer::VERSION_NUMBER => $Lang->getText('Docman.Version'),
	FilesystemPeer::DOWNLOAD_COUNT => $Lang->getText('Docman.Downloads')
);

$count = $parser->getDocCount($subdir);
$paginator = new Paginator('docman', -1, $count, FilesystemPeer::FILE_NAME, $columns);
$theader = $paginator->getSortableTableHeaders($theme);
$nested_docs = $parser->getDocs($subdir, $paginator);

//echo $paginator->showLimitOptions();



echo $theme->tableTop($theader);
if ($count > 0) {
	$trow=array();
	$mods=array('rowspan="'.($count).'"');
	$trow[]=$doctreerenderer->renderNavigation($subdir);
	while ($nested_docs->next()) {
		$url = GFUrl::getURL()->downloadURL(DocmanFileVersion::SECTION,$nested_docs->getInt('docman_file_version_id'),$nested_docs->getInt('filesystem_id'),$nested_docs->getString('file_name_safe'));
		
		// Text that will be used on the tooltip
		$tooltip = StringUtils::trimString($nested_docs->getString('description'), 500);
		$tooltip = StringUtils::generateTooltip($tooltip);
		
		$trow[] = '<a href="'.GFUrl::getURL()->currentBaseUrl('DocmanFileEdit',array('id'=>$nested_docs->getInt('docman_file_id'))).'">'.Language::getSessText('Docman.EditFile').'</a>';
		$trow[] = '<a href="'.$url.'" onMouseOver="tooltip(\''.$tooltip.'\')" onmouseout="tooltipexit()"><img src="/images/docman_doc.gif" height="16" width="16" border="0">&nbsp;'.$nested_docs->getString('file_name_safe').'</a>';
		$trow[] = SystemUtils::getReadableSize($nested_docs->getInt('file_size'));
		//$trow[] = UserPeer::retrieveByPk($nested_docs->getInt('posted_by'))->getName();
		$trow[] = $nested_docs->getString('full_name');
		$trow[] = (( $nested_docs->getBoolean('is_locked') ) ? '&nbsp;<img alt="(locked)" src="/images/locked.png">' : '&nbsp;' );		
		$trow[] = $nested_docs->getInt('version_number');
		$trow[] = $nested_docs->getInt('download_count');
	
		echo $theme->tableRow($trow,$mods,true);

		$trow=array();
		$mods=array();
	}
	//echo $theme->listPaginatorRow($paginator);
} else {
	$trow[] = $doctreerenderer->renderNavigation($subdir);
	$trow[] = Language::getSessText('Docman.NoneFound');
	echo $theme->tableRow($trow,array('rowspan = 1','colspan = 7'),true);
}
	
	if (is_object($Folder) && $session->isLoggedIn()) {
		$DocmanFile = new DocmanFile();
		$DocmanFile->setDocmanFolderId($Folder->getDocmanFolderId());
		if ($DocmanFile->userCanCreate() || $Folder->isPublic()) {
			$bol_create_perms = true;
		} else {
			$bol_create_perms = false;
		}
	} else {
			if (($subdir == '0') && (!is_object($Folder))) {
				$bol_create_perms = true;
			} else {
				$bol_create_perms = false;
			}
	}
	
	if ($bol_create_perms) {		
		echo $theme->tableBottom(array(GFUrl::getURL()->currentBaseUrl('DocmanFileAdd',array('subdir'=>$subdir))=>Language::getSessText('Docman.AddNew')),array(true));
	} else {
		echo $theme->tableBottom(array(''=>Language::getSessText('Docman.AddNew')),array(false));
	}

if(isset($paginator) && is_object($paginator)) {
	echo '<div class="paginator">' . $paginator->getPaginator() . '</div><br />';
}


$theme->footer($params);
?>
