<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 * @date 2005-11-11
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
// The parent class
require_once 'plugins/forum/lib/om/BaseForumThreadPeer.php';

// The object class
include_once 'plugins/forum/lib/ForumThread.php';

/** 
 * The skeleton for this class was autogenerated by Propel on:
 *
 * [Sun Nov 13 22:49:46 2005]
 *
 *  You should add additional methods to this class to meet the
 *  application requirements.  This class will only be generated as
 *  long as it does not already exist in the output directory.
 *
 * @package plugins.forum.lib 
 */
class ForumThreadPeer extends BaseForumThreadPeer {
	private static $_pkCache = array();

	/**
	 * Retrieve a single object by pkey or NULL if not found.
	 * This method was added by propel_customizer.php.
	 *
	 * @param	mixed $pk	The primary key
	 * @param	bool $useCache	Whether to use caching. This will increase performance if the same object
	 *							is accessed several times
	 * @param	Connection $con	The connection to use
	 * @return	ForumThread
	 */
	public static function retrieveByPk($pk, $useCache = true, $con = null) {
		if ($useCache && array_key_exists($pk, ForumThreadPeer::$_pkCache)) {
			return ForumThreadPeer::$_pkCache[$pk];
		}
		
		$object = parent::retrieveByPk($pk, $con);
		if ($useCache) {
			ForumThreadPeer::$_pkCache[$pk] = $object;
		}
		return $object;
	}
	
	/**
	 * Removes an object from the cache. This is usually done after saving.
	 * This method was added by propel_customizer.php.
	 *
	 * @param	mixed $pk	The primary key of the object to remove
	 */
	public static function invalidate($pk) {
		if (array_key_exists($pk, ForumThreadPeer::$_pkCache)) {
			unset(ForumThreadPeer::$_pkCache[$pk]);
		}
	}
	
	/**
	 * Returns the threads active in the last weeks in the forum
	 * @return	array	Array of ForumThread
	 */
	public static function getLatestThreads(Criteria $c) {
		$today_sql = date('Y-m-d', time()+(60*60*24));
		$last_weeks_sql = date('Y-m-d', time()-(60*60*24*7*6));		// Last six weeks
		
		// This emulates a BETWEEN using Propel's Criterion objects
		$criterion = $c->getNewCriterion(self::MOST_RECENT_DATE, $today_sql, Criteria::LESS_EQUAL);
		$criterion->addAnd($c->getNewCriterion(self::MOST_RECENT_DATE, $last_weeks_sql, Criteria::GREATER_EQUAL));
		$c->add($criterion);

		$c->addDescendingOrderByColumn(self::MOST_RECENT_DATE);
		
		return self::doSelectJoinUser($c);
	}
	
	/**
	 * Returns the latest modified threads
	 * @param	int $numthreads	Number of threads to retrieve
	 */
	public static function getTopThreads(Forum $forum, $numthreads = 5) {
		// We must retrieve several objects, so this query must be optimized		
		$sql = '
			SELECT ft.*, fm.*, u.*
			FROM forum_thread AS ft, forum_message AS fm, "user" as u,
				(SELECT ft.forum_thread_id, ft.most_recent_date, MAX(fm.forum_message_id) AS last_message_id
				FROM forum_thread AS ft, forum_message AS fm
				WHERE ft.forum_id='.$forum->getForumId().' AND fm.forum_thread_id=ft.forum_thread_id
				GROUP BY ft.forum_thread_id, ft.most_recent_date
				ORDER BY ft.most_recent_date DESC
				LIMIT '.$numthreads.' OFFSET 0				
				) AS last_thread_data
			WHERE ft.forum_thread_id=last_thread_data.forum_thread_id AND
			fm.forum_message_id=last_thread_data.last_message_id AND
			u.user_id=fm.created_by
		';
		
		$con = Propel::getConnection(self::DATABASE_NAME);
		$stmt = $con->createStatement();
		$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_NUM);
		
		$res = array();
		while ($rs->next()) {
			$item = array();
			$startcol1 = (self::$numColumns - self::$numLazyLoadColumns) + 1;
			$startcol2 = $startcol1 + (ForumMessagePeer::$numColumns - ForumMessagePeer::$numLazyLoadColumns);
			
			$thread = new ForumThread();
			$thread->hydrate($rs);
			
			$last_message = new ForumMessage();
			$last_message->hydrate($rs, $startcol1);
			
			$user = new User();
			$user->hydrate($rs, $startcol2);
			
			$item['thread'] = $thread;
			$item['latest_message'] = $last_message;
			$item['user'] = $user;
			
			$res[] = $item;			
		}
		
		return $res;		
	}
}
?>