<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: index.php 620 2006-03-23 16:13:34Z tperdue $
 * @author Federico Tarantini federico@gforgegroup.com
 * @date 2006-05-24
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('GFUrl.php');
require_once('plugins/scmcc/lib/html/ScmCCTemplate.php');
require_once('plugins/scmcc/lib/CCRepository.php');

$project = GFUrl::getUrl()->getProject();

$ccplugin = $project->getPluginByName('scmcc');
if (is_null($ccplugin)) {
	throw new InvalidPluginException('scmcc');
}

$session = Session::getSession();
$lang = $session->getLanguage();

$template = new ScmccTemplate();
//prevent SCM spider indexation
$indexSCM = false;
if(GFConf::varExists('system.indexSCM')){
	$indexSCM = GFConf::get('system.indexSCM');
}
if(!$indexSCM){
	$extrahead[] = '<META NAME="ROBOTS" CONTENT="NOINDEX,NOFOLLOW" />';
}
$params = array(
	'selectedbottomtab'	=> 'scmcc',
	'project' => $project,
	'action' => isset($action) ? $action : '',
	'feedback' => isset($_REQUEST['feedback']) ? $_REQUEST['feedback'] : (isset($feedback) ? $feedback : ''),
	'title' => $lang->getText('Scmcc.InfoTitle'),
	'extra_head' => $extrahead
	);


$template->header($params);

// See if SCM is configured for this project
$repos = new CCRepository($project);

if ($repos->isConfigured()) {
	//shows CC repository access info
	$conf = $repos->getScmConfiguration();

	// get CC host info
	$hostname = $conf->getHostname();
	$root = $conf->getRootDirectory();
	$custom_access_text = $conf->getAccessText();
	$external_browse_url = $conf->getExternalBrowseUrl();
	$browse_text = $conf->getBrowseText();
?>
<p><h3><?php echo $lang->getText('Scmcc.AccessInfo');?></h3></p>
<p>
	<?php echo $custom_access_text ?>
<table>
	<tr>
		<td><strong><?php echo $lang->getText('Scmcc.Hostname');?>:&nbsp;</strong><?php echo $hostname;?></td>
	</tr>
	<tr>
		<td><strong><?php echo $lang->getText('Scmcc.RootDir');?>:&nbsp;</strong><?php echo $root; ?></td>
	</tr>
</table>
</p>
<?php
	if (!empty($external_browse_url) || !empty($browse_text)) {
?>
<p><h3><?php echo $lang->getText('Scm.ExternalBrowsing') ?></h3></p>
<p>
	<?php echo $browse_text ?><br />
	<?php if (!empty($external_browse_url)) echo '<br /><a href="'.$external_browse_url.'">'.$external_browse_url.'</a>'; ?>
</p>
<?php
	}
} else {
	//if admin, it let you fill the access info
	if ($project->getPermission()->isAdmin()) {
?>
		<a href="<?php echo GFUrl::getUrl()->projectURL($project, '', 'scmcc', 'admin'); ?>"><?php echo $lang->getText('Scmcc.Admin'); ?></a>
<?php
	}
?>
	<p><h3><?php echo $lang->getText('Scm.AdminTitle'); ?></h3></p>

	<p><?php echo $lang->getText('Scm.NotConfigured') ?></p>
<?php
}

$template->footer($params);
?>
