<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli	marcelo@gforgegroup.com
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('SystemUtils.php');
require_once('plugins/scm/lib/SCMRepository.php');

/**
 * Class that redirects requests to the p4web interface
 */
class PerforceBrowser {
	private $repos;
	
	public function __construct(SCMRepository $repos) {
		$this->repos = $repos;
	}

	public function parseQuery($querystring) {
		// read the environment variables for ViewVC from the query string
		$vars = array();
		parse_str($querystring, $vars);
		
		$usep4web = GFConf::get('scmperforce.usep4web');
		if (!$usep4web) {
			throw new PerforceException('Browsing this repository was disabled by the system administrator.');
		}
		
		$url = GFConf::get('scmperforce.p4webUrl');
		// Append a slash to the end if needed
		if (!preg_match('/\\/$/', $url)) {
			$url .= '/';
		}
		
		// Now generate the appropiate URL from the action in the query string
		if (isset($vars['action']) && $vars['action'] == 'browse' && isset($vars['path'])) {
			$path = urldecode($vars['path']);
			$fullpath = SystemUtils::buildFilePath($this->repos->getRoot(), $path);
			if (isset($vars['r1']) && isset($vars['r2'])) {
				// Requested a diff
				$url = $url.'@md=c&cd='.$this->repos->getRoot().'&cdf='.$fullpath.'@'.$fullpath.
						'?ac=19&rev1='.$vars['r1'].'&rev2='.$vars['r2'];
			} else {
				// Regular browsing
				$url = $url.'@md=c&cd='.$this->repos->getRoot().'@'.$fullpath.'?ac=22';
			}
		} else {
			// Browse the root of the repository by default
			$url = $url.'@md=c&cd='.$this->repos->getRoot().'@'.$this->repos->getRoot().'?ac=83';
		}

		GFUrl::redirect($url);
	}
}
?>