<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Ruben Gutierrez	ruben@gforgegroup.com
 * @date 2006-03-13
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('lib/ExcelXML.php');

$session = Session::getSession();
$Project = GFUrl::getUrl()->getProject();
$project_id = $Project->getProjectId();
$Lang = $session->getLanguage();

$con = Propel::getConnection(TrackerPeer::DATABASE_NAME);

$users = array();
$users[0] = 'All';
foreach ($Project->getMembers() as $member) {
	$users[$member->getUserId()] = $member->getFullName();
}

$user_id=((isset($_REQUEST['user_id'])) ? $_REQUEST['user_id'] : 0 );
$begin=((isset($_REQUEST['start_date'])) ? $_REQUEST['start_date'] : 0 );
$end=((isset($_REQUEST['end_date'])) ? $_REQUEST['end_date'] : 0 );
$subprojects=((isset($_REQUEST['subprojects'])) ? Validator::sanitizeInt($_REQUEST['subprojects']) : 0 );

$report=((isset($_GET['report'])) ? $_GET['report'] : 'byUser' );

if ($begin=='0') {
	$begin = (time()-(30*86400));
} else {
	$begin = strtotime($begin);
}
if ($end=='0') {
	$end = time();
} else {
	$end=strtotime($end)+86399;
}
if ($begin > $end) {
	$endtmp=$end;
	$end=$begin;
	$begin=$endtmp;
}

// Get all Project Ids
$all_ids = array();
$all_names = array();
if ($subprojects == 1) {
	$all_ids = $Project->getAllSubprojectIds();
	foreach ($Project->getAllSubprojects() as $subPrj) {
		$all_names[$subPrj->getProjectId()] = $subPrj->getProjectName();
	}
	$all_ids[] = $project_id;
	$all_names[$Project->getProjectId()] = $Project->getProjectName();
} else {
	$all_ids[] = $project_id;
}

// Check if we'll filter by user_id
if ($user_id > 0) {
	$sqluser = "AND tit.user_id = '$user_id'";
} else {
	$sqluser = '';
}

$sqltime = 'AND date_entry BETWEEN \''.date('Y-m-d', $begin).'\' AND \''.date('Y-m-d', $end).'\'';

$book = $Lang->getText('TimeTrackingReporting.DateFrom').' '. date('Y-m-d', $begin). ' ';
$book .= $Lang->getText('TimeTrackingReporting.DateTo').' '.date('Y-m-d', $end);

$filename = 'TimeTrackingReport_';
$excel = new ExcelXML($book);

if ($report == 'byUser') {
	$filename .= 'HoursWorkedByUser';

	/* *****************************
	 * Total Hours Worked By User
	 *******************************/
	
	$excel->setHeader(array('User', $Lang->getText('TimeTrackingReporting.HoursWorked')));
	
	$sql = "SELECT u.user_id, SUM(tit.hours) as hours 
	FROM tracker_item_time tit, \"user\" u, tracker_item ti, tracker t
	WHERE tit.tracker_item_id = ti.tracker_item_id
	AND tit.user_id = u.user_id
	AND ti.tracker_id = t.tracker_id
	AND t.project_id IN (".implode(',',$all_ids).") 
	$sqltime
	$sqluser
	GROUP BY u.user_id ORDER BY hours DESC";
	
	$stmt = $con->createStatement();
	$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
	
	$itemscount = 0;
	
	while($rs->next()) {
		$excel->openRow();
	
		$uid = $rs->getInt('user_id');
		$hours = $rs->getInt('hours');
	
		if (!isset($users[$uid])) {
			$userObj = UserPeer::retrieveByPK($uid);
			$users[$uid] = $userObj->getFullName();
		}
	
		$excel->setCellString($users[$uid]);
		$excel->setCellNumber($hours);
		$excel->closeRow();
	
		$itemscount++;
	}
	
} else if ($report == 'byTracker') {
	$filename .= 'HoursWorkedByTracker';

	/* *****************************
	 * Total Hours Worked By Tracker
	 *******************************/
	
	$excel->setHeader(array('Tracker', $Lang->getText('TimeTrackingReporting.HoursWorked')));
	
	$sql = "SELECT t.tracker_id, t.tracker_name, SUM(tit.hours) as hours, t.project_id 
	FROM tracker_item_time tit, tracker_item ti, tracker t
	WHERE tit.tracker_item_id = ti.tracker_item_id
	AND ti.tracker_id = t.tracker_id
	AND t.project_id IN (".implode(',',$all_ids).") 
	$sqltime
	$sqluser
	GROUP BY t.project_id, t.tracker_id, t.tracker_name ORDER BY hours DESC";
	
	$stmt = $con->createStatement();
	$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
	
	$itemscount = 0;
	while($rs->next()) {
		$excel->openRow();
		
		if ($subprojects == 1) {
			$tracker = $all_names[$rs->getInt('project_id')] . ' > '. $rs->getString('tracker_name');
		} else {
			$tracker = $rs->getString('tracker_name');
		}
		$hours = $rs->getInt('hours');
	
		$excel->setCellString($tracker);
		$excel->setCellNumber($hours);
		$excel->closeRow();
		$itemscount++;
	}
} else if ($report == 'inCategories') {
	$filename .= 'HoursWorkedByUserInCateg';
	
	/* *****************************
	 * Hours Worked By User In Categories
	 *******************************/
	 
	$excel->setHeader(array('User', $Lang->getText('TrackerItemTime.TrackerTimeCodeIdName'),
					$Lang->getText('TimeTrackingReporting.HoursWorked')));
	
	$sql = "SELECT u.user_id, ttc.tracker_time_code_id, ttc.time_name, SUM(tit.hours) as hours 
	FROM tracker_item_time tit, \"user\" u, tracker_time_code ttc, tracker_item ti, tracker t
	WHERE tit.tracker_item_id = ti.tracker_item_id
	AND tit.user_id = u.user_id
	AND tit.tracker_time_code_id = ttc.tracker_time_code_id
	AND ti.tracker_id = t.tracker_id
	AND t.project_id IN (".implode(',',$all_ids).") 
	$sqltime
	$sqluser
	GROUP BY u.user_id, ttc.tracker_time_code_id, ttc.time_name
	ORDER BY u.user_id, hours DESC";
	
	$stmt = $con->createStatement();
	$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
	
	$lastUser=0;
	$itemscount = 0;
	
	$rows = array();
	$uids = array();
	
	while($rs->next()) {
		$uid = $rs->getInt('user_id');
	
		if (!isset($uids[$uid])) {
			$uids[$uid] = 0;
		}
		if (!isset($users[$uid])) {
			$userObj = UserPeer::retrieveByPK($uid);
			$users[$uid] = $userObj->getFullName();
		}
		
		$uids[$uid]++;
		$rows[] = array('uid'=>$uid,'user_name'=>$users[$uid], 'time_name'=>$rs->getString('time_name'), 'hours'=>$rs->getString('hours'));
	
	}
	
	foreach ($rows as $row) {
		$excel->openRow();

		if ($row['uid'] != $lastUser) {
			$lastUser = $row['uid'];
			$excel->setCellString($row['user_name']);
		} else {
			$excel->setCellString('');
		}

		$excel->setCellString($row['time_name']);
		$excel->setCellNumber($row['hours']);
		$excel->closeRow();
	
		$itemscount++;
	}
} else if ($report == 'inTrackers') {
	$filename .= 'HoursWorkedByUserInTrackers';
	
	/* *****************************
	 * Hours Worked By User In Trackers
	 *******************************/

	$excel->setHeader(array('User', 'Tracker', $Lang->getText('TimeTrackingReporting.HoursWorked')));
	
	$sql = "SELECT u.user_id, t.tracker_id, t.tracker_name, SUM(tit.hours) as hours, t.project_id 
	FROM tracker_item_time tit, \"user\" u, tracker_item ti, tracker t
	WHERE tit.tracker_item_id = ti.tracker_item_id
	AND tit.user_id = u.user_id
	AND ti.tracker_id = t.tracker_id
	AND t.project_id IN (".implode(',',$all_ids).") 
	$sqltime
	$sqluser
	GROUP BY t.project_id, t.tracker_id, t.tracker_name, u.user_id
	ORDER BY u.user_id, hours DESC";
	
	$stmt = $con->createStatement();
	$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
	
	$lastUser=0;
	$itemscount = 0;
	
	$rows = array();
	$uids = array();
	
	while($rs->next()) {
		$uid = $rs->getInt('user_id');
		$pid = $rs->getInt('project_id');
	
		if (!isset($uids[$uid])) {
			$uids[$uid] = 0;
		}
		if (!isset($users[$uid])) {
			$userObj = UserPeer::retrieveByPK($uid);
			$users[$uid] = $userObj->getFullName();
		}
		
		$uids[$uid]++;
		$rows[] = array('pid'=>$pid,'uid'=>$uid,'user_name'=>$users[$uid], 'tracker_name'=>$rs->getString('tracker_name'), 'hours'=>$rs->getString('hours'));
	
	}
	
	foreach ($rows as $row) {
		$excel->openRow();
		
		if ($row['uid'] != $lastUser) {
			$lastUser = $row['uid'];
			$excel->setCellString($row['user_name']);
		} else {
			$excel->setCellString('');
		}

		if ($subprojects == 1) {
			$excel->setCellString($all_names[$row['pid']] . ' > '. $row['tracker_name']);
		} else {
			$excel->setCellString($row['tracker_name']);
		}
		$excel->setCellNumber($row['hours']);
		$excel->closeRow();
	
		$itemscount++;
	}
} else if ($report == 'inItems') {
	$filename .= 'HoursWorkedByUserInItems';
	
	/* *****************************
	 * Hours Worked By User In Tracker Items
	 *******************************/
	 
	$excel->setHeader(array('User', 'Tracker', $Lang->getText('TimeTrackingReporting.TrackerItem'),
					$Lang->getText('TimeTrackingReporting.HoursWorked')));
	
	$sql = "SELECT u.user_id, t.tracker_id, t.tracker_name, ti.tracker_item_id, ti.summary, SUM(tit.hours) as hours, t.project_id 
	FROM tracker_item_time tit, \"user\" u, tracker_item ti, tracker t
	WHERE tit.tracker_item_id = ti.tracker_item_id
	AND tit.user_id = u.user_id
	AND t.tracker_id = ti.tracker_id
	AND t.project_id IN (".implode(',',$all_ids).") 
	$sqltime
	$sqluser
	GROUP BY t.project_id, ti.tracker_item_id, u.user_id, t.tracker_id, t.tracker_name, ti.summary 
	ORDER BY u.user_id, t.tracker_name, hours DESC";
	
	$stmt = $con->createStatement();
	$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_ASSOC);
	
	$lastUser=0;
	$lastTracker=0;
	$itemscount = 0;
	
	while($rs->next()) {
		$pid = $rs->getInt('project_id');
		$uid = $rs->getInt('user_id');
		$tid = $rs->getInt('tracker_id');
	
		if (!isset($uids[$uid])) {
			$uids[$uid] = 0;
		}
		if (!isset($users[$uid])) {
			$userObj = UserPeer::retrieveByPK($uid);
			$users[$uid] = $userObj->getFullName();
		}
		
		if (!isset($tids[$tid])) {
			$tids[$tid] = array();
		}
		if (!isset($tids[$tid][$uid])) {
			$tids[$tid][$uid] = 0;
		}
	
		$uids[$uid]++;
		$tids[$tid][$uid]++;
		$rows[] = array('pid'=>$pid,'uid'=>$uid,'user_name'=>$users[$uid], 'tid'=>$tid, 'tracker_name'=>$rs->getString('tracker_name'),'summary'=>$rs->getString('summary'), 'hours'=>$rs->getString('hours'));
	
	}
	
	foreach ($rows as $row) {
		$excel->openRow();
		
		if ($row['uid'] != $lastUser) {
			$lastUser = $row['uid'];
			$excel->setCellString($row['user_name']);
		} else {
			$excel->setCellString('');
		}
		if ($row['tid'] != $lastTracker) {
			$lastTracker = $row['tid'];

			if ($subprojects == 1) {
				$excel->setCellString($all_names[$row['pid']] . ' > '. $row['tracker_name']);
			} else {
				$excel->setCellString($row['tracker_name']);
			}
		} else {
			$excel->setCellString('');
		}
	
		$excel->setCellString($row['summary']);
		$excel->setCellNumber($row['hours']);
		$excel->closeRow();

		$itemscount++;
	}
}

header("Content-Type: application/vnd.ms-excel");
header("Expires: 0");
header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
header("content-disposition: attachment;filename=$filename.xls");
echo $excel->getXML();
exit();
?>
