<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 * @date 2006-02-27
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */


require_once('session/LoginFactory.php');
require_once('Validator.php');
require_once('plugin/ActionManager.php');

$login = LoginFactory::getLogin();
$ip = $_SERVER["REMOTE_ADDR"];
$error = "";

if (isset($_REQUEST['username']) || (GFConf::get('system.useSSO') && isset($_SERVER[GFConf::get('system.SSOServerVar')]))) {
	try {
		//sso begin
		if (GFConf::get('system.useSSO')) {
			//query the database to get the user account info to auto-login
			//based on the presented SSO ID
			//the remote address may need to be split and take only the first part
			$tmpsplitchar=GFConf::get('system.SSOServerVarSplitChar');
			if (!empty($tmpsplitchar)) {
				$tmpserverid=explode(GFConf::get('system.SSOServerVarSplitChar'), $_SERVER[GFConf::get('system.SSOServerVar')]);
				$_SERVER[GFConf::get('system.SSOServerVar')]=$tmpserverid[0];
			}

			$c = new Criteria(UserPeer::DATABASE_NAME);
			if (GFConf::get('system.SSOIDMatchesUnixName')) {
				$c->add(UserPeer::UNIX_NAME, strtolower($_SERVER[GFConf::get('system.SSOServerVar')]));
			} else {
				$c->add(UserPeer::EXTERNAL_ID, $_SERVER[GFConf::get('system.SSOServerVar')]);
			}
			$user = UserPeer::doSelectOne($c);

			if (is_null($user)) {
				// Redirect to the register page. The user name will be filled
				// with the SM user name.

				GFUrl::redirect(GFUrl::getUrl()->baseUrl('UserAdd', '', 'account'));
				exit;
			}
			
			if ($user->getStatus() != User::STATUS_ACTIVE) {
				throw new Exception(Language::getSessText('User.AccountDisabled'));
			}

			$userSession = new UserSession();
			$userSession->setUser($user);
			$_REQUEST['username']=$user->getUnixName();
			$_REQUEST['password']=$user->getPasswordMd5();

		} else {
			//non-sso login
			$userSession = $login->doLogin($_REQUEST['username'], $_REQUEST['password']);
		}
		
		$session = Session::getSession();
		$session->setUserSession($userSession, $ip);
		$sessionHash = $session->getSessionHash();
	
		$sessionTimeout = GFConf::get("system.sessionTimeout");
		if ($sessionTimeout>0) {
			setcookie("sessionHash", $sessionHash, time()+$sessionTimeout, "/");	
		} else {    
			setcookie("sessionHash", $sessionHash, 0, "/");	
		}

		$params = array('username' => $_REQUEST['username'], 
						'password' => $_REQUEST['password']);
		ActionManager::notify('USER_LOGIN', $params);

		if(isset($_REQUEST['redirect']) && !empty($_REQUEST['redirect']) && Validator::validateRedirect($_REQUEST['redirect'])) { 
			header("Location: ".$_REQUEST['redirect']);
		} else {
			header("Location: /gf/my/");
		}

	} catch (LoginException $e) {
		$feedback = $e->getMessage();
		require_once('Login.php');
	}
} else {
	$feedback = '* '.Language::getSessText('Common.UsernameRequired');;
	include('Login.php');
}

?>
