<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code creates a new UsergroupUser and saves it to the 
// database
//
require_once('core/UsergroupUser.php');
require_once('Validator.php');
require_once('exceptions/InvalidDataException.php');
require_once('exceptions/PermissionDeniedException.php');
require_once('core/Language.php');

if ($_SERVER['REQUEST_METHOD'] != 'POST') {
	throw new PermissionDeniedException();
}
$Lang = Language::getSessLang();

$errors = array();
$group_id = Validator::sanitizeInt($_POST['id']);
$unixname = strtolower(Validator::sanitizeString($_POST['unix_name']));

$User = UserPeer::retrieveByUnixName($unixname);
if (is_object($User) && $User->getStatus() == User::STATUS_ACTIVE) {
	$user_id = $User->getId();

	// Check to see if the $User is already Member of $group
	$crit=new Criteria();
	$crit->add(UsergroupUserPeer::USERGROUP_ID,$group_id);
	$crit->add(UsergroupUserPeer::MEMBER_USER_ID,$user_id);
	$ugu = UsergroupUserPeer::doSelect($crit);
	if (count($ugu) > 0) {
		$errors[] = $Lang->getText('UsergroupUser.AlreadyMember');
	}

} else {
	$errors[] = $Lang->getText('UsergroupUser.MemberNotExist');
}

$Group = UserPeer::retrieveByPk($group_id);
if (!is_object($Group) || $Group->getIsGroup() != true) {
	throw new PermissionDeniedException();
}


if (count($errors) == 0) {

	$UsergroupUser = new UsergroupUser();

	try {
		$UsergroupUser->setUsergroupId($group_id);
		$UsergroupUser->setMemberUserId($user_id);
		$UsergroupUser->save();
		GFUrl::redirect(GFUrl::getUrl()->currentBaseURL('UsergroupEdit'), array('id' => $group_id, 'feedback' => $Lang->getText('UsergroupUser.AddFeedback')));
	} catch (InvalidDataException $ex) {
		$errors = array_merge($errors, $ex->getErrors());		// attach object errors to validation errors
		$feedback = '* '.implode('<br />* ', $errors);
		include('UsergroupUserAdd.php');

	}
} else {
	$feedback = '* '.implode('<br />* ', $errors);
	include('UsergroupUserAdd.php');
}
?>
