<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Ruben Gutierrez	ruben@gforgegroup.com
 * @date 2006-03-13
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once ('lib/external/jpgraph/jpgraph.php');
require_once ('lib/external/jpgraph/jpgraph_gantt.php');

$session = Session::getSession();
$Lang = $session->getLanguage();
$user = $session->getUser();

$user_id = $user->getUserId();
$tracker_id=((isset($_GET['tracker_id'])) ? $_GET['tracker_id'] : 0 );
$begin=((isset($_GET['start_date'])) ? $_GET['start_date'] : 0 );
$end=((isset($_GET['end_date'])) ? $_GET['end_date'] : 0 );
$sortord=((isset($_GET['sortord'])) ? $_GET['sortord'] : 'ASC' );
$sortcol=((isset($_GET['sortcol']) && $_GET['sortcol'] != '') ? $_GET['sortcol'] : 'open_date' );
$res=((isset($_GET['resolution'])) ? $_GET['resolution'] : null );
$size=((isset($_GET['size'])) ? $_GET['size'] : null );

if ($begin=="0") {
	$begin = (time()-(30*86400));
} else {
	$begin = strtotime($begin);
}
if ($end=="0") {
	$end = time();
} else {
	$end=strtotime($end)+86399;
}
if ($begin > $end) {
	$endtmp=$end;
	$end=$begin;
	$begin=$endtmp;
}

$c = new Criteria();
$c->add(TrackerItemPeer::OPEN_DATE, $begin, Criteria::GREATER_EQUAL);
$c->addAnd(TrackerItemPeer::OPEN_DATE, $end, Criteria::LESS_EQUAL);
$c->addJoin(TrackerItemPeer::TRACKER_ID, TrackerPeer::TRACKER_ID);
$c->add(TrackerPeer::DATATYPE, Tracker::DATATYPE_TASK);
$c->addJoin(TrackerItemPeer::TRACKER_ITEM_ID, TrackerItemAssigneePeer::TRACKER_ITEM_ID);
$c->add(TrackerItemAssigneePeer::ASSIGNEE, $user_id);
$c->addAscendingOrderByColumn(TrackerPeer::PROJECT_ID);

if ($tracker_id != 0) {
	$c->add(TrackerItemPeer::TRACKER_ID, $tracker_id);
}

if ($sortord == 'DESC') {
	$c->addDescendingOrderByColumn('tracker_item.'.strtoupper($sortcol));
} else {
	$c->addAscendingOrderByColumn('tracker_item.'.strtoupper($sortcol));
}

$items = TrackerItemPeer::doSelect($c);

if ($size==640) {
	$graph = new GanttGraph (590,480);
} elseif ($size==1024) {
	$graph  = new GanttGraph (974,768);
} elseif ($size==1600) {
	$graph = new GanttGraph (1550,1200);
} else {
	$graph = new GanttGraph (750,600);
}

$font = $Lang->getFontProperties(FF_FONT2, FS_BOLD, 12);

$graph->SetMargin(10,10,25,20);
$graph->title->Set($Lang->getText('MyGanttView.Title'));
$graph->title->SetFont($font[0], $font[1], $font[2]);

if ($res == 'Days') {
	$graph->ShowHeaders(GANTT_HDAY | GANTT_HWEEK | GANTT_HMONTH);
} elseif ($res == 'Weeks') {
	$graph->ShowHeaders(GANTT_HWEEK | GANTT_HMONTH);
} else {
	$graph->ShowHeaders(GANTT_HMONTH);
}

$graph->scale->week->SetStyle(WEEKSTYLE_FIRSTDAY);
$graph->scale->week->SetFont(FF_FONT0);
$graph->scale->month->SetStyle(MONTHSTYLE_SHORTNAMEYEAR2);

$i = 0;
$dependencies = array();
$cache = array();
$gantbars = array();

$font = $Lang->getFontProperties(FF_FONT1, FS_NORMAL, 9);
// Create GanttBar objects
foreach($items as $task) {
	$task_id = $task->getTrackerItemId();
	$bar = new GanttBar ($i, $task->getSummary(), date('Y-m-d', $task->getOpenDate(null)), date('Y-m-d', $task->getCloseDate(null)-86400));
	$bar->title->SetFont($font[0], $font[1], $font[2]);

	$relations = $task->getTrackerItemRelationsRelatedByTrackerItemId();
	$extra = $task->getTrackerExtraFieldDatas();
	$extra_ids = $task->getTracker()->getTrackerExtraFields();

	$complete_id = 0;
	$complete = 0;

	foreach ($relations as $rel) {
		$dependencies[$task_id]=array($rel->getLinkType()=>$rel->getRelatedTrackerItemId());
	}
	foreach ($extra_ids as $field) {
		if ($field->getAlias() == 'percentcomplete') { $complete_id = $field->getTrackerExtraFieldId(); }
	}
	foreach ($extra as $data) {
		if ($data->getTrackerExtraFieldId() == $complete_id) { $complete = ($data->getFieldData() / 100); }
	}
	
	$bar->progress->Set($complete);
	$gantbars[$task_id] = $bar;
	$cache[$task_id] = $i;
	$i++;
}

// Add GanttBars to Graph

foreach($gantbars as $key => $bar) {
	if (isset($dependencies[$key])) {
		list($linktype, $depkey) = each($dependencies[$key]);

		switch($linktype){
			case 'SS':
				$lt = CONSTRAIN_STARTSTART;
				break;
			case 'SF':
				$lt = CONSTRAIN_STARTEND;
				break;
			case 'FS':
				$lt = CONSTRAIN_ENDSTART;
				break;
			case 'FF':
				$lt = CONSTRAIN_ENDEND;
				break;
		}
		if (isset($cache[$depkey])) {
			$bar->SetConstrain($cache[$depkey],$lt); 
		}
	}
	$graph->Add($bar);
}

$todayline = new GanttVLine(date('Y-m-d',time()), 'Today');
$todayline ->SetDayOffset (0.5);
$graph->Add($todayline);
$graph->Stroke();
?>
